@@ -113,7 +113,7 @@ void ServerTestPrivate::finalResult()
 
     QVector<int> resultsAsVector;
     resultsAsVector.reserve(connectionResults.size());
-    for (int res : qAsConst(connectionResults)) {
+    for (int res : std::as_const(connectionResults)) {
         resultsAsVector.append(res);
     }
 
@@ -236,8 +236,8 @@ bool ServerTestPrivate::handlePopConversation(MailTransport::Socket *socket, int
     // Initial Greeting
     if (stage == 0) {
         // Regexp taken from POP3 ioslave
-        const QString responseWithoutCRLF = response.chopped(2);
-        const QRegularExpression re(QStringLiteral("<[A-Za-z0-9\\.\\-_]+@[A-Za-z0-9\\.\\-_]+>$"), QRegularExpression::CaseInsensitiveOption);
+        const QString responseWithoutCRLF = response.isEmpty() ? response : response.chopped(2);
+        static const QRegularExpression re(QStringLiteral("<[A-Za-z0-9\\.\\-_]+@[A-Za-z0-9\\.\\-_]+>$"), QRegularExpression::CaseInsensitiveOption);
         if (responseWithoutCRLF.indexOf(re) != -1) {
             authenticationResults[type] << Transport::EnumAuthenticationType::APOP;
         }
@@ -343,8 +343,13 @@ bool ServerTestPrivate::handleNntpConversation(MailTransport::Socket *socket, in
         //     SASL DIGEST-MD5 CRAM-MD5 NTLM PLAIN LOGIN
         //     STARTTLS
         //     .
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        const QVector<QStringView> lines = QStringView(response).split(QStringLiteral("\r\n"), Qt::SkipEmptyParts);
+        for (const QStringView line : lines) {
+#else
         const QVector<QStringRef> lines = response.splitRef(QStringLiteral("\r\n"), Qt::SkipEmptyParts);
         for (const QStringRef &line : lines) {
+#endif
             if (line.compare(QLatin1String("STARTTLS"), Qt::CaseInsensitive) == 0) {
                 *shouldStartTLS = true;
             } else if (line.startsWith(QLatin1String("AUTHINFO "), Qt::CaseInsensitive)) {
@@ -527,14 +532,11 @@ ServerTest::ServerTest(QObject *parent)
     connect(d->progressTimer, SIGNAL(timeout()), SLOT(slotUpdateProgress()));
 }
 
-ServerTest::~ServerTest()
-{
-    delete d;
-}
+ServerTest::~ServerTest() = default;
 
 void ServerTest::start()
 {
-    qCDebug(MAILTRANSPORT_LOG) << d;
+    qCDebug(MAILTRANSPORT_LOG) << d.get();
 
     d->connectionResults.clear();
     d->authenticationResults.clear();
