@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTMANAGER_H
-#define MAILTRANSPORT_TRANSPORTMANAGER_H
+#pragma once
 
 #include <mailtransport_export.h>
 #include <transporttype.h>
@@ -13,11 +12,15 @@
 #include <QList>
 #include <QObject>
 
-namespace KWallet {
+#include <memory>
+
+namespace KWallet
+{
 class Wallet;
 }
 
-namespace MailTransport {
+namespace MailTransport
+{
 class Transport;
 class TransportJob;
 class TransportManagerPrivate;
@@ -42,7 +45,6 @@ class MAILTRANSPORT_EXPORT TransportManager : public QObject
     friend class TransportManagerPrivate;
 
 public:
-
     /**
       Destructor.
     */
@@ -147,8 +149,8 @@ public:
 
     /// Describes when to show the transport creation dialog
     enum ShowCondition {
-        Always,              ///< Show the transport creation dialog unconditionally
-        IfNoTransportExists  ///< Only show the transport creation dialog if no transport currently
+        Always, ///< Show the transport creation dialog unconditionally
+        IfNoTransportExists ///< Only show the transport creation dialog if no transport currently
         ///  exists. Ask the user if he wants to add a transport in
         ///  the other case.
     };
@@ -174,6 +176,7 @@ public:
     bool configureTransport(const QString &identifier, Transport *transport, QWidget *parent);
 
     void initializeTransport(const QString &identifier, Transport *transport);
+
 public:
     /**
       Returns true if there are no mail transports at all.
@@ -268,16 +271,14 @@ protected:
     TransportManager();
 
 private:
-
     // These are used by our friend, Transport
     void emitChangesCommitted();
     void updatePluginList();
 
 private:
-    TransportManagerPrivate *const d;
+    std::unique_ptr<TransportManagerPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void slotTransportsChanged())
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTMANAGER_H
